dpgen run machine parameters
============================
.. note::
   One can load, modify, and export the input file by using our effective web-based tool `DP-GUI <https://deepmodeling.com/dpgui/input/dpgen-machine>`_. All parameters below can be set in DP-GUI. By clicking "SAVE JSON", one can download the input file.

.. dargs::
   :module: dpgen.generator.arginfo
   :func: run_mdata_arginfo
